#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 show-combinators
version:              0.2.0.0
visibility:           public
id:                   show-combinators-0.2.0.0-8mcquj5XLUT8kVqwDvrwi2
key:                  show-combinators-0.2.0.0-8mcquj5XLUT8kVqwDvrwi2
license:              MIT
copyright:            2018 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/show-combinators#readme
synopsis:             Combinators to write Show instances
description:
    A minimal pretty-printing library for Show instances in Haskell.

category:             Text
abi:                  94aa9743bb036f1dabc9ef13888b862e
exposed:              True
exposed-modules:      Text.Show.Combinators
import-dirs:          /usr/lib/ghc-9.6.6/site-local/show-combinators-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/show-combinators-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/show-combinators-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-show-combinators
hs-libraries:         HSshow-combinators-0.2.0.0-8mcquj5XLUT8kVqwDvrwi2
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-show-combinators/html/show-combinators.haddock

haddock-html:         /usr/share/doc/haskell-show-combinators/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

